==> agrum-2.1.0-1-x86_64.pkg.tar.zst: usr/lib/python3.13/site-packages/pyagrum/ctbn/__init__.py <==
############################################################################
#   This file is part of the aGrUM/pyAgrum library.                        #
#                                                                          #
#   Copyright (c) 2005-2025 by                                             #
#       - Pierre-Henri WUILLEMIN(_at_LIP6)                                 #
#       - Christophe GONZALES(_at_AMU)                                     #
#                                                                          #
#   The aGrUM/pyAgrum library is free software; you can redistribute it    #
#   and/or modify it under the terms of either :                           #
#                                                                          #
#    - the GNU Lesser General Public License as published by               #
#      the Free Software Foundation, either version 3 of the License,      #
#      or (at your option) any later version,                              #
#    - the MIT license (MIT),                                              #
#    - or both in dual license, as here.                                   #
#                                                                          #
#   (see https://agrum.gitlab.io/articles/dual-licenses-lgplv3mit.html)    #
#                                                                          #
#   This aGrUM/pyAgrum library is distributed in the hope that it will be  #
#   useful, but WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,          #
#   INCLUDING BUT NOT LIMITED TO THE WARRANTIES MERCHANTABILITY or FITNESS #
#   FOR A PARTICULAR PURPOSE  AND NONINFRINGEMENT. IN NO EVENT SHALL THE   #
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER #
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,        #
#   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR  #
#   OTHER DEALINGS IN THE SOFTWARE.                                        #
#                                                                          #
#   See the GNU Lesser General Public License (LICENSE.LGPL) and the MIT   #
#   licence (LICENSE.MIT) for more details.                                #
#                                                                          #
#   Contact  : info_at_agrum_dot_org                                       #
#   homepage : http://agrum.gitlab.io                                      #
#   gitlab   : https://gitlab.com/agrumery/agrum                           #
#                                                                          #
############################################################################

"""

"""

__author__ = "Pierre-Henri Wuillemin, Rodolphe Tavernier"
__copyright__ = "(c) 2022-2023 PARIS"

from .CIM import CIM
from .CTBN import CTBN
from .CTBNGenerator import randomCTBN
from .CTBNInference import CTBNInference, SimpleInference, ForwardSamplingInference
from .SamplesStats import readTrajectoryCSV, CTBNFromData, computeCIMFromStats, Trajectory, Stats, plotTrajectory, \
  plotFollowVar
from .StatsIndepTest import IndepTest, FChi2Test
from .CTBNLearner import Learner

__all__ = ['CIM',
           'CTBN',
           'randomCTBN',
           'CTBNInference', 'SimpleInference', 'ForwardSamplingInference',
           'readTrajectoryCSV', 'CTBNFromData', 'computeCIMFromStats', 'Trajectory', 'Stats', 'plotTrajectory',
           'plotFollowVar',
           'IndepTest', 'FChi2Test',
           'Learner']

==> agrum-2.2.0-1-x86_64.pkg.tar.zst: usr/lib/python3.13/site-packages/pyagrum/ctbn/__init__.py <==
############################################################################
#   This file is part of the aGrUM/pyAgrum library.                        #
#                                                                          #
#   Copyright (c) 2005-2025 by                                             #
#       - Pierre-Henri WUILLEMIN(_at_LIP6)                                 #
#       - Christophe GONZALES(_at_AMU)                                     #
#                                                                          #
#   The aGrUM/pyAgrum library is free software; you can redistribute it    #
#   and/or modify it under the terms of either :                           #
#                                                                          #
#    - the GNU Lesser General Public License as published by               #
#      the Free Software Foundation, either version 3 of the License,      #
#      or (at your option) any later version,                              #
#    - the MIT license (MIT),                                              #
#    - or both in dual license, as here.                                   #
#                                                                          #
#   (see https://agrum.gitlab.io/articles/dual-licenses-lgplv3mit.html)    #
#                                                                          #
#   This aGrUM/pyAgrum library is distributed in the hope that it will be  #
#   useful, but WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,          #
#   INCLUDING BUT NOT LIMITED TO THE WARRANTIES MERCHANTABILITY or FITNESS #
#   FOR A PARTICULAR PURPOSE  AND NONINFRINGEMENT. IN NO EVENT SHALL THE   #
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER #
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,        #
#   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR  #
#   OTHER DEALINGS IN THE SOFTWARE.                                        #
#                                                                          #
#   See the GNU Lesser General Public License (LICENSE.LGPL) and the MIT   #
#   licence (LICENSE.MIT) for more details.                                #
#                                                                          #
#   Contact  : info_at_agrum_dot_org                                       #
#   homepage : http://agrum.gitlab.io                                      #
#   gitlab   : https://gitlab.com/agrumery/agrum                           #
#                                                                          #
############################################################################

""" """

__author__ = "Pierre-Henri Wuillemin, Rodolphe Tavernier"
__copyright__ = "(c) 2022-2023 PARIS"

from .CIM import CIM
from .CTBN import CTBN
from .CTBNGenerator import randomCTBN
from .CTBNInference import CTBNInference, SimpleInference, ForwardSamplingInference
from .SamplesStats import (
  readTrajectoryCSV,
  CTBNFromData,
  computeCIMFromStats,
  Trajectory,
  Stats,
  plotTrajectory,
  plotFollowVar,
)
from .StatsIndepTest import IndepTest, FChi2Test
from .CTBNLearner import Learner

__all__ = [
  "CIM",
  "CTBN",
  "randomCTBN",
  "CTBNInference",
  "SimpleInference",
  "ForwardSamplingInference",
  "readTrajectoryCSV",
  "CTBNFromData",
  "computeCIMFromStats",
  "Trajectory",
  "Stats",
  "plotTrajectory",
  "plotFollowVar",
  "IndepTest",
  "FChi2Test",
  "Learner",
]
